pub struct CascadeResponse {
pub display_name: String,
pub callers: Vec<String>,
pub users: Vec<String>,
pub match_functions: Vec<String>,
pub containing_types: Vec<String>,
}Expand description
Response from cascade analysis.
For detailed type impact analysis, use graph type instead.
Fields
display_name: StringDisplay name of the target symbol.
callers: Vec<String>Functions/methods that call the target.
users: Vec<String>Types/functions that use the target as a type reference.
match_functions: Vec<String>Functions containing match expressions on this enum. Only populated when the target is an Enum.
containing_types: Vec<String>Types that contain this type as a field.